@@ -9,7 +9,7 @@ from textual.widgets.option_list import Option
 from modaic import AutoProgram, PrecompiledProgram
 
 from .cache import load_model_config, save_model_config
-from .constants import AVAILABLE_MODELS, BOLD, GREEN, RED, RESET
+from .constants import AVAILABLE_MODELS, GREEN, RED, RESET
 
 
 def normalize_model_id(model_id: str) -> str:
@@ -133,13 +133,6 @@ def select_model() -> str:
             click.echo(f"{RED}⏺ Invalid model ID{RESET}")
             continue
 
-        name = next(
-            name
-            for name, model_id in AVAILABLE_MODELS.values()
-            if model_id == selection
-        )
-
-        click.echo(f"{GREEN}⏺ Selected: {name}{RESET}")
         return selection
 
 
@@ -183,12 +176,6 @@ def select_sub_model(primary_model: str) -> str:
             click.echo(f"{RED}⏺ Invalid sub model ID{RESET}")
             continue
 
-        name = next(
-            name
-            for name, model_id in AVAILABLE_MODELS.values()
-            if model_id == selection
-        )
-        click.echo(f"{GREEN}⏺ Selected sub model: {name}{RESET}")
         return selection
 
 
@@ -281,13 +268,6 @@ def handle_model_command(
     assert callable(register_mcp_server), "register_mcp_server must be callable"
     assert isinstance(repo_path, str), "repo_path must be a str"
 
-    print(
-        f"\n{BOLD}Current RLM(model): {agent.config.lm.removeprefix('openrouter/')}{RESET}"
-    )
-    print(
-        f"{BOLD}Current sub model: {agent.config.sub_lm.removeprefix('openrouter/')}{RESET}"
-    )
-
     new_model = agent.config.lm
     model_selection = prompt_model_tui(
         "Select a base RLM model:",
@@ -319,16 +299,9 @@ def handle_model_command(
             print(f"{RED}⏺ Invalid model ID, keeping current model{RESET}")
             return True, agent, normalize_model_id(agent.config.sub_lm)
         new_model = normalize_model_id(custom_model)
-        print(f"{GREEN}⏺ Selected custom model: {new_model}{RESET}")
 
     else:
         new_model = normalize_model_id(model_selection)
-        name = next(
-            name
-            for name, model_id in AVAILABLE_MODELS.values()
-            if model_id == model_selection
-        )
-        print(f"{GREEN}⏺ Selected: {name} ({new_model}){RESET}")
 
     sub_selection = prompt_model_tui(
         "Select the RLM's sub model (usually a smaller, faster model than the base):",
@@ -341,15 +314,9 @@ def handle_model_command(
 
     if sub_selection is None or sub_selection == KEEP_OPTION:
         new_sub_lm = normalize_model_id(agent.config.sub_lm)
-        print(
-            f"{GREEN}⏺ Keeping current sub model: {new_sub_lm.removeprefix('openrouter/')}{RESET}"
-        )
 
     elif sub_selection == PRIMARY_OPTION:
         new_sub_lm = normalize_model_id(new_model)
-        print(
-            f"{GREEN}⏺ sub model set to primary model: {new_sub_lm.removeprefix('openrouter/')}{RESET}"
-        )
 
     elif sub_selection == CUSTOM_OPTION:
         custom_sub = click.prompt(
@@ -359,20 +326,13 @@ def handle_model_command(
         ).strip()
 
         if not custom_sub:
-            print(f"{RED}⏺ Invalid sub model ID, keeping current sub model{RESET}")
             new_sub_lm = normalize_model_id(agent.config.sub_lm)
 
         else:
             new_sub_lm = normalize_model_id(custom_sub)
-            print(
-                f"{GREEN}⏺ Selected custom sub model: {new_sub_lm.removeprefix('openrouter/')}{RESET}"
-            )
 
     else:
         new_sub_lm = normalize_model_id(sub_selection)
-        print(
-            f"{GREEN}⏺ Selected sub model: {new_sub_lm.removeprefix('openrouter/')}{RESET}"
-        )
 
     config = {"lm": normalize_model_id(new_model), "sub_lm": new_sub_lm}
     for key in ("max_iters", "max_tokens", "max_output_chars", "api_base", "verbose"):
@@ -388,7 +348,4 @@ def handle_model_command(
         info["tools"] = register_mcp_server(agent, server_name, info["server"])
 
     save_model_config(normalize_model_id(new_model), new_sub_lm)
-    click.echo(
-        f"{GREEN}⏺ Switched to: {normalize_model_id(new_model)} | sub model: {new_sub_lm.removeprefix('openrouter/')}{RESET}"
-    )
     return True, agent, new_sub_lm
